<?php
namespace Bushelpowered\Api\Platform\Location\V1\Model;
        
class LocationRaw implements \Bushelpowered\Api\Common\Event\RawRecord, \Bushelpowered\Api\Common\HasSourceTimestamps
{
    /** @var string $tenantId The tenant identifier.*/
    public string $tenantId;
    /** @var string $datasourceId The datasource identifier.*/
    public string $datasourceId;
    /** @var string $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.*/
    public string $integrationId;
    /** @var string $sourceId The source record identifier.*/
    public string $sourceId;
    /** @var string $sourceName The record's source name*/
    public string $sourceName;
    /** @var null|string $physicalAddressLine1 First line of a standard US postal address*/
    public ?string $physicalAddressLine1 = null;
    /** @var null|string $physicalAddressLine2 Second line of a standard US postal address*/
    public ?string $physicalAddressLine2 = null;
    /** @var null|string $physicalLocality Physical locality*/
    public ?string $physicalLocality = null;
    /** @var null|string $physicalAdministrativeArea Physical administrative area*/
    public ?string $physicalAdministrativeArea = null;
    /** @var null|string $physicalPostalCode Physical postal code*/
    public ?string $physicalPostalCode = null;
    /** @var null|string $physicalCountryCode Physical country code*/
    public ?string $physicalCountryCode = null;
    /** @var string[]|null $businessType The list of business types for the location.  Expected options include Grain Delivery, Agronomy, Office, Plant, Seed and Feed*/
    public ?array $businessType = null;
    /** @var null|string $businessPhone Business phone*/
    public ?string $businessPhone = null;
    /** @var null|string $businessFax Business fax*/
    public ?string $businessFax = null;
    /** @var null|string $businessEmail Business Email*/
    public ?string $businessEmail = null;
    /** @var null|string $businessWebsite Business website*/
    public ?string $businessWebsite = null;
    /** @var null|string $sourceAccountId The datasource's remote id of the account that owns this record, if any.*/
    public ?string $sourceAccountId = null;
    /** @var null|string $sourceLocationId The datasource's remote id of the location that owns this record, if any.*/
    public ?string $sourceLocationId = null;
    /** @var string $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceUpdatedAt;
    /** @var string $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public string $sourceCreatedAt;
    /** @var null|string $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00*/
    public ?string $sourceDeletedAt = null;

    /**
     * @param  string  $tenantId The tenant identifier.
     * @param  string  $datasourceId The datasource identifier.
     * @param  string  $integrationId The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     * @param  string  $sourceId The source record identifier.
     * @param  string  $sourceName The record's source name
     * @param  null|string  $physicalAddressLine1 First line of a standard US postal address
     * @param  null|string  $physicalAddressLine2 Second line of a standard US postal address
     * @param  null|string  $physicalLocality Physical locality
     * @param  null|string  $physicalAdministrativeArea Physical administrative area
     * @param  null|string  $physicalPostalCode Physical postal code
     * @param  null|string  $physicalCountryCode Physical country code
     * @param  string[]|null  $businessType The list of business types for the location.  Expected options include Grain Delivery, Agronomy, Office, Plant, Seed and Feed
     * @param  null|string  $businessPhone Business phone
     * @param  null|string  $businessFax Business fax
     * @param  null|string  $businessEmail Business Email
     * @param  null|string  $businessWebsite Business website
     * @param  null|string  $sourceAccountId The datasource's remote id of the account that owns this record, if any.
     * @param  null|string  $sourceLocationId The datasource's remote id of the location that owns this record, if any.
     * @param  string  $sourceUpdatedAt The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  string  $sourceCreatedAt When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     * @param  null|string  $sourceDeletedAt The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function __construct(string $tenantId, string $datasourceId, string $integrationId, string $sourceId, string $sourceName, ?string $physicalAddressLine1, ?string $physicalAddressLine2, ?string $physicalLocality, ?string $physicalAdministrativeArea, ?string $physicalPostalCode, ?string $physicalCountryCode, ?array $businessType, ?string $businessPhone, ?string $businessFax, ?string $businessEmail, ?string $businessWebsite, ?string $sourceAccountId, ?string $sourceLocationId, string $sourceUpdatedAt, string $sourceCreatedAt, ?string $sourceDeletedAt)
    {
        $this->tenantId = $tenantId;
        $this->datasourceId = $datasourceId;
        $this->integrationId = $integrationId;
        $this->sourceId = $sourceId;
        $this->sourceName = $sourceName;
        $this->physicalAddressLine1 = $physicalAddressLine1;
        $this->physicalAddressLine2 = $physicalAddressLine2;
        $this->physicalLocality = $physicalLocality;
        $this->physicalAdministrativeArea = $physicalAdministrativeArea;
        $this->physicalPostalCode = $physicalPostalCode;
        $this->physicalCountryCode = $physicalCountryCode;
        $this->businessType = $businessType;
        $this->businessPhone = $businessPhone;
        $this->businessFax = $businessFax;
        $this->businessEmail = $businessEmail;
        $this->businessWebsite = $businessWebsite;
        $this->sourceAccountId = $sourceAccountId;
        $this->sourceLocationId = $sourceLocationId;
        $this->sourceUpdatedAt = $sourceUpdatedAt;
        $this->sourceCreatedAt = $sourceCreatedAt;
        $this->sourceDeletedAt = $sourceDeletedAt;
    }
    
    /**
     * @return string The tenant identifier.
     */
    public function getTenantId(): string
    {
        return $this->tenantId;
    }
    /**
     * @return string The datasource identifier.
     */
    public function getDatasourceId(): string
    {
        return $this->datasourceId;
    }
    /**
     * @return string The global unique identifier of the source record, often concatenation of the datasource and source identifiers to ensure uniqueness.
     */
    public function getIntegrationId(): string
    {
        return $this->integrationId;
    }
    /**
     * @return string The source record identifier.
     */
    public function getSourceId(): string
    {
        return $this->sourceId;
    }
    /**
     * @return null|string The datasource's remote id of the account that owns this record, if any.
     */
    public function getSourceAccountId(): ?string
    {
        return $this->sourceAccountId;
    }
    /**
     * @return null|string The datasource's remote id of the location that owns this record, if any.
     */
    public function getSourceLocationId(): ?string
    {
        return $this->sourceLocationId;
    }
    /**
     * @return string The last time this record was updated. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceUpdatedAt(): string
    {
        return $this->sourceUpdatedAt;
    }
    /**
     * @return string When the record was created. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceCreatedAt(): string
    {
        return $this->sourceCreatedAt;
    }
    /**
     * @return null|string The time the record was deleted. Null if not deleted. of RFC-3339 format, IE: 2023-10-04T21:26:22+00:00
     */
    public function getSourceDeletedAt(): ?string
    {
        return $this->sourceDeletedAt;
    }
}